sqlobject.manager package
=========================

.. automodule:: sqlobject.manager
    :members:
    :undoc-members:
    :show-inheritance:

Submodules
----------

.. toctree::

   sqlobject.manager.command

